# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   test_56
# FileName:      read_ini.py
# Author:       xxxxxxx
# Datetime:     2023/8/4 14:12
# Description:
# 
# ---------------------------------------------------------------------------
import configparser
import os


class ReadIni:
    def __init__(self):
        """获取ini文件的路径，在读取ini文件"""
        self.data_config_path = os.path.join(os.path.dirname(os.path.dirname(__file__)), "data_config")
        ini_path = os.path.join(self.data_config_path, "config.ini")
        self.conf = configparser.ConfigParser()
        self.conf.read(ini_path, encoding="utf-8")

    def get_file_path(self, key):
        """
        根据key，获取file节点下key对应的文件的路径
        :param key: 键
        :return:文件的路径
        """
        # 使用Configparser对象调用get方法，获取file节点下key对应的文件名称
        file_name = self.conf.get("file", key).strip()
        # 返回拼接的文件路径
        return os.path.join(self.data_config_path, file_name)

    def get_host(self, key):
        """
        根据key，获取被测系统的域名
        :param key: 键
        :return: 域名
        """
        # 使用Configparser对象调用get方法，获取host节点下key对应的域名
        return self.conf.get("host", key).strip()

    def get_table_name(self, key):
        """
        根据key，获取excel工作表的名称
        :param key: 键
        :return: 表名
        """
        # 使用Configparser对象调用get方法，获取table_name节点下key对应的excel工作表的名称
        return self.conf.get("table_name", key).strip()

    def get_sql_connect_message(self, key):
        """
        根据key，获取数据库的链接信息
        :param key: 键
        :return: 数据库的链接信息
        """
        # 使用Configparser对象调用get方法，获取sql节点下key对应的值
        return self.conf.get("sql", key).strip()
